diff --git a/lib/util.php b/lib/util.php
index 7af28c920f000da7e5e8f562637c8894182f859c..c6b164adbe8e972e318ec7e4815e63b70ab9fa29 100755
--- a/lib/util.php
+++ b/lib/util.php
@@ -594,8 +594,8 @@ class OC_Util {
 			}
 		}
 
-		// Try to use /dev/random
-		$fp = @file_get_contents('/dev/random', false, null, 0, $length);
+		// Try to use /dev/urandom
+		$fp = @file_get_contents('/dev/urandom', false, null, 0, $length);
 		if ($fp !== FALSE) {
 			$string = substr(bin2hex($fp), 0, $length);
 			return $string;
@@ -628,8 +628,8 @@ class OC_Util {
 			}
 		}
 
-		// Check /dev/random
-		$fp = @file_get_contents('/dev/random', false, null, 0, 1);
+		// Check /dev/urandom
+		$fp = @file_get_contents('/dev/urandom', false, null, 0, 1);
 		if ($fp !== FALSE) {
 			return true;
 		}